package com.fizz.business.mapper;

import java.util.List;
import com.fizz.business.domain.SetupTl;
import org.apache.ibatis.annotations.Param;

/**
 * 拉矫机参数Mapper接口
 * 
 * @author ruoyi
 * @date 2025-09-26
 */
public interface SetupTlMapper 
{
    /**
     * 查询拉矫机参数
     * 
     * @param steelGrade 拉矫机参数主键
     * @return 拉矫机参数
     */
    public SetupTl selectSetupTlBySteelGrade(@Param("steelGrade") String steelGrade,@Param("yieldStren") Long yieldStren,@Param("thick") Long thick);

    /**
     * 查询拉矫机参数列表
     * 
     * @param setupTl 拉矫机参数
     * @return 拉矫机参数集合
     */
    public List<SetupTl> selectSetupTlList(SetupTl setupTl);

    /**
     * 新增拉矫机参数
     * 
     * @param setupTl 拉矫机参数
     * @return 结果
     */
    public int insertSetupTl(SetupTl setupTl);

    /**
     * 修改拉矫机参数
     * 
     * @param setupTl 拉矫机参数
     * @return 结果
     */
    public int updateSetupTl(SetupTl setupTl);

    /**
     * 删除拉矫机参数
     * 
     * @param steelGrade 拉矫机参数主键
     * @return 结果
     */
    public int deleteSetupTlBySteelGrade(String steelGrade);

    /**
     * 批量删除拉矫机参数
     * 
     * @param steelGrades 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSetupTlBySteelGrades(@Param("steelGrades") String[] steelGrades,@Param("yieldStrens") Long[] yieldStrens,@Param("thicks") Long[] thicks);
}
